#
# spec file for package python-line_profiler
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-line_profiler
Version:        1.0
Release:        2.3
Url:            http://packages.python.org/line_profiler
Summary:        Line-by-line profiler
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/l/line_profiler/line_profiler-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-nose
Requires(post): update-alternatives
Requires(postun): update-alternatives
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%description
line_profiler will profile the time individual lines of code take to execute.
The profiler is implemented in C via Cython in order to reduce the overhead of
profiling.

Also included is the script kernprof.py which can be used to conveniently
profile Python applications and scripts either with line_profiler or with the
function-level profiling tools in the Python standard library.

%prep
%setup -q -n line_profiler-%{version}

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/kernprof %{buildroot}%{_bindir}/kernprof-%{py_ver}
ln -s  %{_bindir}/kernprof-%{py_ver} %{buildroot}%{_bindir}/kernprof

%pre
# Since /usr/bin/kernprof became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/kernprof ] || rm -f %{_bindir}/kernprof

%post
update-alternatives \
   --install %{_bindir}/kernprof kernprof %{_bindir}/kernprof-%{py_ver} 30 

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove kernprof %{_bindir}/kernprof-%{py_ver}
fi

%clean
rm -rf %{buildroot}

%check
pushd line_profiler.egg-info
PYTHONPATH="%{buildroot}%{python_sitearch}" nosetests
popd

%files
%defattr(-,root,root,-)
%doc LICENSE.txt LICENSE_Python.txt README.rst
%ghost %{_bindir}/kernprof
%{_bindir}/kernprof-%{py_ver}
%{python_sitearch}/_line_profiler.so
%{python_sitearch}/line_profiler-%{version}-py*.egg-info
%{python_sitearch}/line_profiler.py
%{python_sitearch}/line_profiler.pyc
%{python_sitearch}/kernprof.py
%{python_sitearch}/kernprof.pyc

%changelog
* Tue Nov 11 2014 toddrme2178@gmail.com
- Implement update-alternatives
- Implement unit tests
* Thu Oct  2 2014 termim@gmail.com
- Update to 1.0
  * `kernprof.py` is now installed as `kernprof`.
  * Python 3 support. Thanks to the long-suffering Mikhail Korobov for
    being patient.
  * Dropped 2.6 as it was too annoying.
  * The `stripzeros` and `add_module` options. Thanks to Erik Tollerud
    for contributing it.
  * Support for IPython cell blocks. Thanks to Michael Forbes for adding
    this feature.
  * Better warnings when building without Cython. Thanks to David
    Cournapeau for spotting this.
* Mon Mar 10 2014 toddrme2178@gmail.com
- Update to 1.0b3
  * Profile generators.
  * Update for compatibility with newer versions of Cython.
    Thanks to Ondrej Certik for spotting the bug.
  * Update IPython compatibility for 0.11+. Thanks to Yaroslav
    Halchenko and others for providing the updated imports.
* Fri Jul  1 2011 saschpe@suse.de
- Initial version
